---
title: "getNumberFormatter"
parent: "@messageformat/number-skeleton"
grand_parent: API Reference
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->



# getNumberFormatter() function

Returns a number formatter function for the given locales and number skeleton

<b>Signature:</b>

```typescript
export declare function getNumberFormatter(locales: string | string[], skeleton: string | Skeleton, currency?: string | null, onError?: (err: NumberFormatError) => void): (value: number) => string;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  locales | string \| string\[\] | One or more valid BCP 47 language tags, e.g. <code>fr</code> or <code>en-CA</code> |
|  skeleton | string \| [Skeleton](./number-skeleton.skeleton.md) | An ICU NumberFormatter pattern or <code>::</code>-prefixed skeleton string, or a parsed <code>Skeleton</code> structure |
|  currency | string \| null | <i>(Optional)</i> If <code>skeleton</code> is a pattern string that includes ¤ tokens, their skeleton representation requires a three-letter currency code. |
|  onError | (err: [NumberFormatError](./number-skeleton.numberformaterror.md)<!-- -->) =&gt; void | <i>(Optional)</i> If defined, will be called separately for each encountered parsing error and unsupported feature. |

<b>Returns:</b>

(value: number) =&gt; string

## Remarks

Uses `Intl.NumberFormat` (ES2020) internally.

## Example


```js
import { getNumberFormatter } from '@messageformat/number-skeleton'

let src = ':: currency/CAD unit-width-narrow'
let fmt = getNumberFormatter('en-CA', src, console.error)
fmt(42) // '$42.00'

src = '::percent scale/100'
fmt = getNumberFormatter('en', src, console.error)
fmt(0.3) // '30%'
```

